#  tests for kealib-1.5.0-hde4a422_0 (this is a generated file);
print('===== testing package: kealib-1.5.0-hde4a422_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---

# just load kealib using ctypes
import os
import sys
import ctypes

if sys.platform == 'win32':
    path = os.path.join(sys.prefix, 'Library', 'bin', 'libkea.dll')
    kealib = ctypes.CDLL(path)
elif sys.platform == 'darwin':
    path = os.path.expandvars('$PREFIX/lib/libkea.dylib')
    kealib = ctypes.CDLL(path)
elif sys.platform.startswith('linux'):
    path = os.path.expandvars('$PREFIX/lib/libkea.so')
    kealib = ctypes.CDLL(path)
else:
    raise Exception('Cannot recognize platform {!r}'.format(sys.platform))

#  --- run_test.py (end) ---

print('===== kealib-1.5.0-hde4a422_0 OK =====');
