@echo off

IF "%1"=="" (
   echo kea-config.bat [OPTIONS]
   echo Options:
   echo     [--prefix]
   echo     [--version]
   echo     [--libs]
   echo     [--cflags]
   echo     [--includes]
   EXIT /B 1
) ELSE (
:printValue
    if "%1" neq "" (
	    IF "%1"=="--prefix" echo C:/b/abs_b5kovquvd1/croot/kealib_1674215869641/_h_env/Library
	    IF "%1"=="--version" echo 1.5.0
	    IF "%1"=="--cflags" echo -IC:/b/abs_b5kovquvd1/croot/kealib_1674215869641/_h_env/Library/include
	    IF "%1"=="--libs" echo -LIBPATH:C:/b/abs_b5kovquvd1/croot/kealib_1674215869641/_h_env/Library/lib libkea.lib 
	    IF "%1"=="--includes" echo C:/b/abs_b5kovquvd1/croot/kealib_1674215869641/_h_env/Library/include
		shift
		goto :printValue
    )
	EXIT /B 0
)
